@@ -1,13 +1,13 @@
 import setuptools
 
-with open("README.md", "r", encoding="utf-8") as fh:
+with open("README.md", "r") as fh:
     long_description = fh.read()
 
-with open("requirements.txt", "r", encoding="utf-8") as fh:
-    requirements = fh.read().splitlines(keepends=False)
+with open("requirements.txt", "r") as fh:
+    requirements = fh.read().splitlines(False)
 
 setuptools.setup(
-    name="example-pkg-YOUR-USERNAME-HERE",
+    name="{{ name }}",
     version="0.0.1",
     author="Example Author",
     author_email="author@example.com",
